emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/emacs-24 r108091: Add new load commands for


From: YAMAMOTO Mitsuharu
Subject: [Emacs-diffs] /srv/bzr/emacs/emacs-24 r108091: Add new load commands for OS X 10.8.
Date: Tue, 07 Aug 2012 12:47:26 +0900
User-agent: Bazaar (2.5.0)

------------------------------------------------------------
revno: 108091
committer: YAMAMOTO Mitsuharu <address@hidden>
branch nick: emacs-24
timestamp: Tue 2012-08-07 12:47:26 +0900
message:
  Add new load commands for OS X 10.8.
modified:
  src/ChangeLog
  src/unexmacosx.c
=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2012-07-19 03:33:08 +0000
+++ b/src/ChangeLog     2012-08-07 03:47:26 +0000
@@ -1,3 +1,9 @@
+2012-08-07  YAMAMOTO Mitsuharu  <address@hidden>
+
+       * unexmacosx.c (print_load_command_name): Add cases LC_MAIN,
+       LC_SOURCE_VERSION, and LC_DYLIB_CODE_SIGN_DRS.
+       (dump_it) [LC_DYLIB_CODE_SIGN_DRS]: Call copy_linkedit_data.
+
 2012-07-19  Chong Yidong  <address@hidden>
 
        * window.c (Fwindow_absolute_pixel_edges)

=== modified file 'src/unexmacosx.c'
--- a/src/unexmacosx.c  2012-01-19 07:21:25 +0000
+++ b/src/unexmacosx.c  2012-08-07 03:47:26 +0000
@@ -609,6 +609,21 @@
       printf ("LC_FUNCTION_STARTS");
       break;
 #endif
+#ifdef LC_MAIN
+    case LC_MAIN:
+      printf ("LC_MAIN          ");
+      break;
+#endif
+#ifdef LC_SOURCE_VERSION
+    case LC_SOURCE_VERSION:
+      printf ("LC_SOURCE_VERSION");
+      break;
+#endif
+#ifdef LC_DYLIB_CODE_SIGN_DRS
+    case LC_DYLIB_CODE_SIGN_DRS:
+      printf ("LC_DYLIB_CODE_SIGN_DRS");
+      break;
+#endif
     default:
       printf ("unknown          ");
     }
@@ -1146,8 +1161,9 @@
 #endif
 
 #ifdef LC_FUNCTION_STARTS
-/* Copy a LC_FUNCTION_STARTS load command from the input file to the
-   output file, adjusting the data offset field.  */
+/* Copy a LC_FUNCTION_STARTS/LC_DYLIB_CODE_SIGN_DRS load command from
+   the input file to the output file, adjusting the data offset
+   field.  */
 static void
 copy_linkedit_data (struct load_command *lc, long delta)
 {
@@ -1241,6 +1257,9 @@
 #endif
 #ifdef LC_FUNCTION_STARTS
       case LC_FUNCTION_STARTS:
+#ifdef LC_DYLIB_CODE_SIGN_DRS
+      case LC_DYLIB_CODE_SIGN_DRS:
+#endif
        copy_linkedit_data (lca[i], linkedit_delta);
        break;
 #endif


reply via email to

[Prev in Thread] Current Thread [Next in Thread]